import React, {useRef, useState} from 'react';
import {createUseStyles} from "react-jss";

const useClass = createUseStyles({
    container: {
        width: "calc(100% - 45px)",
        height: "calc(100% - 45px)",
        margin: "20px",
        border: "1px solid #ddd",
        borderRadius: "8px",
        overflow: "hidden",
        position: "relative",
    },
    input_box: {
        width: "100%",
        height: "100%",
        padding: "10px",
        boxSizing: "border-box",
        border: "none",
        resize: "none",
        outline: "none",
        fontFamily: "Arial, sans-serif",
        transition: "padding 0.3s ease",
    },
    input_has_files: {
        paddingTop: '50px',
    },
    file_list: {
        position: "absolute",
        top: "0",
        left: "0",
        right: "0",
        padding: "8px 10px",
        background: "rgba(255, 255, 255, 0.95)",
        borderBottom: "1px solid #eee",
        display: "none",
        flexWrap: "wrap",
        gap: "6px",
        maxHeight: "60px",
        overflowY: "auto",
    },
    list_has_files: {
        display: 'flex'
    },
    "@keyframes slideIn": {
        from: {transform: "translateY(-10px)", opacity: 0},
        to: {transform: "translateY(0)", opacity: 1}
    },
    file_item: {
        display: "flex",
        alignItems: "center",
        background: "#f0f6ff",
        color: '#1661ab',
        border: "1px solid #c2d9ff",
        borderRadius: "15px",
        padding: "4px 12px",
        fontSize: "13px",
        animation: "$slideIn 0.2s ease"
    },
    delete_btn: {
        width: "16px",
        height: "16px",
        border: "none",
        background: "#ff6b6b",
        color: "white",
        borderRadius: "50%",
        marginLeft: "8px",
        cursor: "pointer",
        display: "flex",
        alignItems: "center",
        justifyContent: "center",
        fontSize: "12px",
        "&:hover": {background: "#ff5252"},
    },
    buttons: {
        position: "absolute",
        bottom: "10px",
        right: "10px",
        display: "flex",
        gap: "8px"
    },
    action_btn: {
        padding: "8px 16px",
        background: "#4dabf7",
        color: "white",
        border: "none",
        borderRadius: "20px",
        cursor: "pointer",
        transition: "all 0.2s",
        "&:hover": {background: "#339af0", transform: "translateY(-1px)"}
    },
})

export interface SenderProps {
    onSend: (message: string, files: File[]) => void;
}

export const Sender: React.FC<SenderProps> = ({onSend}) => {
    const classes = useClass();
    const [message, setMessage] = useState('');
    const [files, setFiles] = useState<File | null>(null);
    const fileInputRef = useRef<HTMLInputElement>(null)

    const handleTextInput = (e: React.ChangeEvent<HTMLTextAreaElement>) => {
        setMessage(e.target.value)
    }

    const handleFileSelect = (e: React.ChangeEvent<HTMLInputElement>) => {
        if (e.target.files) {
            setFiles(e.target.files[0]);
        }
    };

    const handleSubmit = () => {
        if (message.trim() || files) {
            onSend(message, files?[files]:[]);
            setMessage('');
            setFiles(null);
        }
    };

    return (
        <div className={classes.container}>
            <textarea className={files?`${classes.input_box} ${classes.input_has_files}`:`${classes.input_box}`} placeholder="开始输入..."
                      onChange={handleTextInput}>{message}</textarea>
            <div className={files? `${classes.file_list} ${classes.list_has_files}` : `${classes.file_list}`}>
                {files && <div className={classes.file_item}>
                    <span>{files.name}</span>
                    <button className={classes.delete_btn} onClick={() => {
                        setFiles(null)
                    }}>×
                    </button>
                </div>}
            </div>
            <div className={classes.buttons}>
                <input type="file" ref={fileInputRef} hidden onChange={handleFileSelect}/>
                <button className={classes.action_btn} onClick={() => {
                    fileInputRef.current && fileInputRef.current.click()
                }}>📁 选择文件
                </button>
                <button className={classes.action_btn} onClick={handleSubmit}>✈️ 发送</button>
            </div>
        </div>
    );
};